@@ -619,8 +619,9 @@ class BaseCacheTests:
         cache.key_func = func
 
         try:
-            with self.assertWarnsMessage(CacheKeyWarning, expected_warning):
+            with self.assertWarns(CacheKeyWarning) as cm:
                 cache.set(key, 'value')
+            self.assertEqual(str(cm.warning), expected_warning)
         finally:
             cache.key_func = old_func
 
@@ -1256,9 +1257,10 @@ class BaseMemcachedTests(BaseCacheTests):
         Whilst other backends merely warn, memcached should raise for an
         invalid key.
         """
-        msg = expected_warning.replace(key, ':1:%s' % key)
-        with self.assertRaisesMessage(InvalidCacheKey, msg):
+        msg = expected_warning.replace(key, cache.make_key(key))
+        with self.assertRaises(InvalidCacheKey) as cm:
             cache.set(key, 'value')
+        self.assertEqual(str(cm.exception), msg)
 
     def test_default_never_expiring_timeout(self):
         # Regression test for #22845
